@@ -276,6 +276,8 @@ def _guess_loader():
     if ext in [".json"]:
         return json.load, ext
 
+def get_config_dir():
+    return _local_config_dir
 
 def _load_from_local_file() -> dict:
     """
@@ -309,13 +311,12 @@ def _load_from_local_file() -> dict:
                 _mixin(conf, _test)
 
         else:
-            try:
-                with open(os.path.join(_local_config_dir, f"dev{ext}"), "r", encoding='utf-8') as dev:
-                    _dev = loader(dev)
-                    _mixin(conf, _dev)
-            except FileNotFoundError:
-                pass
-
+            with open(os.path.join(_local_config_dir, f"dev{ext}"), "r", encoding='utf-8') as dev:
+                _dev = loader(dev)
+                _mixin(conf, _dev)
+    except FileNotFoundError as e:
+        if e.filename.find('defaults') != -1:
+            raise FileNotFoundError("Failed to find default configuration file")
     except Exception as e:
         logger.exception(e)
 
@@ -323,5 +324,5 @@ def _load_from_local_file() -> dict:
 
 
 # noinspection PyUnusedLocal
-def config_server(role: str):
-    print("Not implemented yet.")
+def config_server_role(role: str):
+    os.environ[envar] = role
